@@ -65,6 +65,71 @@ setMethod("merge", c(CMAT, "ANY"), function(x, y) {
   new(CMAT, x)
 }, sealed = SEALED)
 
+setGeneric("split")
+
+setMethod("split", c(OPMX, "missing", "missing"), function(x, f, drop) {
+  split(x, drop = FALSE)
+}, sealed = SEALED)
+
+setMethod("split", c(OPM, "missing", "logical"), function(x, f, drop) {
+  extract_concentration <- function(x) {
+    m <- regexpr("(?<=#)\\s*\\d+\\s*$", x, FALSE, TRUE)
+    conc <- as.integer(substr(x, m, m + attr(m, "match.length") - 1L))
+    regmatches(x, m) <- "1"
+    list(Concentration = conc, Standardized = structure(names(x), names = x))
+  }
+  regular_size <- function(x) {
+    counts <- tabulate(x$Concentration)
+    length(counts) > 1L || all(duplicated.default(counts)[-1L])
+  }
+  regular_composition <- function(x) {
+    for (i in seq_along(x)[-1L])
+      if (!setequal(names(x[[1L]]), names(x[[i]])))
+        return(FALSE)
+    TRUE
+  }
+  get_and_rename <- function(x, w1, w2, conc, drop, key) {
+    x <- rename_wells(x[, w1, drop = drop], w2)
+    x@metadata[[key]] <- conc
+    x
+  }
+  w <- extract_concentration(wells(x, TRUE, FALSE))
+  if (!regular_size(w) || !regular_composition(
+      w <- split.default(w$Standardized, w$Concentration))) {
+    warning("no regular concentration structure found")
+    return(x)
+  }
+  for (i in seq_along(w)[-1L])
+    w[[i]] <- w[[i]][names(w[[1L]])]
+  new(OPMS, plates = mapply(get_and_rename, conc = as.integer(names(w)),
+    w1 = w, SIMPLIFY = FALSE, USE.NAMES = FALSE, MoreArgs = list(x = x,
+      w2 = w[[1L]], drop = drop, key = get("series.key", OPM_OPTIONS))))
+}, sealed = SEALED)
+
+setMethod("split", c(OPMS, "missing", "logical"), function(x, f, drop) {
+  x@plates <- lapply(x@plates, split, drop = drop)
+  x@plates <- unlist(lapply(x@plates, slot, "plates"), FALSE, FALSE)
+  x
+}, sealed = FALSE)
+
+setMethod("split", c(OPMX, "ANY", "missing"), function(x, f, drop) {
+  split(x, f, FALSE)
+}, sealed = SEALED)
+
+setMethod("split", c(OPM, "factor", "logical"), function(x, f, drop) {
+  object <- split.default(0L, f, FALSE) # to get the warnings/errors
+  object[[1L]] <- x[drop = drop]
+  new(MOPMX, object)
+}, sealed = SEALED)
+
+setMethod("split", c(OPMS, "factor", "logical"), function(x, f, drop) {
+  new(MOPMX, lapply(split.default(x, f, FALSE), `[`, drop = drop))
+}, sealed = SEALED)
+
+setMethod("split", c(OPMX, "ANY", "logical"), function(x, f, drop) {
+  split(x, as.factor(extract_columns(x, f, TRUE, " ", "ignore")), drop)
+}, sealed = SEALED)
+
 setGeneric("plates", function(object, ...) standardGeneric("plates"))
 
 setMethod("plates", OPMS, function(object) {
@@ -368,6 +433,31 @@ setMethod("extract", "data.frame", function(object, as.groups = TRUE,
 setGeneric("extract_columns",
   function(object, ...) standardGeneric("extract_columns"))
 
+setMethod("extract_columns", OPM, function(object, what, join = FALSE,
+    sep = " ", dups = c("warn", "error", "ignore"), factors = TRUE,
+    exact = TRUE, strict = TRUE) {
+  what <- metadata_key(what, FALSE, NULL)
+  result <- metadata(object, what, exact, strict)
+  result <- if (is.list(result))
+    rapply(result, as.character)
+  else
+    as.character(result)
+  if (L(join)) {
+    result <- paste0(result, collapse = sep)
+  } else {
+    result <- as.list(result)
+    if (is.null(names(result)))
+      names(result) <- paste0(what, collapse = get("key.join", OPM_OPTIONS))
+    result <- as.data.frame(result, optional = TRUE, stringsAsFactors = factors)
+    if (ncol(result) > length(colnames(result)))
+      colnames(result) <- paste0(what, collapse = get("key.join", OPM_OPTIONS))
+    if (is.list(attr(what, "combine")))
+      result <- extract_columns(result, attr(what, "combine"),
+        factors = factors, direct = TRUE)
+  }
+  result
+}, sealed = SEALED)
+
 setMethod("extract_columns", OPMS, function(object, what, join = FALSE,
     sep = " ", dups = c("warn", "error", "ignore"), factors = TRUE,
     exact = TRUE, strict = TRUE) {
@@ -399,7 +489,7 @@ setMethod("extract_columns", OPMS, function(object, what, join = FALSE,
 
 setMethod("extract_columns", "data.frame", function(object, what,
     as.labels = NULL, as.groups = NULL, sep = opm_opt("comb.value.join"),
-    factors = is.list(what), direct = inherits(what, "AsIs")) {
+    factors = is.list(what), direct = is.list(what) || inherits(what, "AsIs")) {
   join <- function(x, what, sep)
     do.call(paste, c(x[, what, drop = FALSE], list(sep = sep)))
   find_stuff <- function(x, what) {
@@ -444,49 +534,80 @@ setMethod("extract_columns", "data.frame", function(object, what,
 setGeneric("as.data.frame")
 
 setMethod("as.data.frame", OPM, function(x, row.names = NULL,
-    optional = FALSE, sep = "_", ...,
-    stringsAsFactors = default.stringsAsFactors()) {
-  result <- cbind(as.data.frame(as.list(x@csv_data[CSV_NAMES]), NULL, optional,
-    ..., stringsAsFactors = stringsAsFactors), Well = wells(x))
+    optional = FALSE, sep = "_", csv.data = TRUE, settings = TRUE,
+    include = FALSE, ..., stringsAsFactors = default.stringsAsFactors()) {
+  result <- as.data.frame(wells(x), NULL, optional, ...,
+    stringsAsFactors = stringsAsFactors)
+  colnames(result) <- RESERVED_NAMES[["well"]]
+  if (L(csv.data))
+    result <- cbind(as.data.frame(as.list(x@csv_data[CSV_NAMES]), NULL,
+      optional, ..., stringsAsFactors = stringsAsFactors), result)
+  if (is.logical(include)) {
+    if (L(include))
+      result <- cbind(result, to_metadata(x, stringsAsFactors, optional))
+  } else if (length(include)) {
+    result <- cbind(result, extract_columns(object = x, what = include,
+      factors = stringsAsFactors))
+  }
   rownames(result) <- row.names
-  colnames(result) <- gsub("\\W+", sep, colnames(result), FALSE, TRUE)
+  if (length(sep))
+    colnames(result) <- gsub("\\W+", sep, colnames(result), FALSE, TRUE)
   result
 }, sealed = SEALED)
 
 setMethod("as.data.frame", OPMA, function(x, row.names = NULL,
-    optional = FALSE, sep = "_", ...,
-    stringsAsFactors = default.stringsAsFactors()) {
+    optional = FALSE, sep = "_", csv.data = TRUE, settings = TRUE,
+    include = FALSE, ..., stringsAsFactors = default.stringsAsFactors()) {
   result <- as.data.frame(t(x@aggregated), NULL, optional, ...,
     stringsAsFactors = stringsAsFactors)
-  colnames(result) <- gsub("\\W+", sep, colnames(result), FALSE, TRUE)
-  result <- cbind(callNextMethod(x, row.names, optional, sep, ...,
-    stringsAsFactors = stringsAsFactors), result)
-  settings <- x@aggr_settings[c(SOFTWARE, VERSION, METHOD)]
-  names(settings) <- paste("Aggr", names(settings), sep = sep)
-  cbind(result, as.data.frame(settings, NULL, optional, ...,
-    stringsAsFactors = stringsAsFactors))
+  if (length(sep))
+    colnames(result) <- gsub("\\W+", sep, colnames(result), FALSE, TRUE)
+  result <- cbind(callNextMethod(x, row.names, optional, sep, csv.data,
+    settings, include, ..., stringsAsFactors = stringsAsFactors), result)
+  if (L(settings)) {
+    settings <- x@aggr_settings[c(SOFTWARE, VERSION, METHOD)]
+    if (length(sep)) {
+      names(settings) <- gsub("\\W+", sep, names(settings), FALSE, TRUE)
+      names(settings) <- paste("Aggr", names(settings), sep = sep)
+    } else
+      names(settings) <- paste("Aggr", names(settings),
+        sep = get("comb.key.join", OPM_OPTIONS))
+    result <- cbind(result, as.data.frame(settings, NULL, optional, ...,
+      stringsAsFactors = stringsAsFactors))
+  }
+  result
 }, sealed = SEALED)
 
 setMethod("as.data.frame", OPMD, function(x, row.names = NULL,
-    optional = FALSE, sep = "_", ...,
-    stringsAsFactors = default.stringsAsFactors()) {
-  result <- callNextMethod(x, row.names, optional, sep, ...,
-    stringsAsFactors = stringsAsFactors)
+    optional = FALSE, sep = "_", csv.data = TRUE, settings = TRUE,
+    include = FALSE, ..., stringsAsFactors = default.stringsAsFactors()) {
+  result <- callNextMethod(x, row.names, optional, sep, csv.data, settings,
+    include, ..., stringsAsFactors = stringsAsFactors)
   result$Discretized <- x@discretized
-  settings <- x@disc_settings[c(SOFTWARE, VERSION, METHOD)]
-  names(settings) <- paste("Disc", names(settings), sep = sep)
-  cbind(result, as.data.frame(settings, NULL, optional, ...,
-    stringsAsFactors = stringsAsFactors))
+  if (settings) {
+    settings <- x@disc_settings[c(SOFTWARE, VERSION, METHOD)]
+    if (length(sep)) {
+      names(settings) <- gsub("\\W+", sep, names(settings), FALSE, TRUE)
+      names(settings) <- paste("Disc", names(settings), sep = sep)
+    } else
+      names(settings) <- paste("Disc", names(settings),
+        sep = get("comb.key.join", OPM_OPTIONS))
+    result <- cbind(result, as.data.frame(settings, NULL, optional, ...,
+      stringsAsFactors = stringsAsFactors))
+  }
+  result
 }, sealed = SEALED)
 
 setMethod("as.data.frame", OPMS, function(x, row.names = NULL,
-    optional = FALSE, sep = "_", ...,
-    stringsAsFactors = default.stringsAsFactors()) {
+    optional = FALSE, sep = "_", csv.data = TRUE, settings = TRUE,
+    include = FALSE, ..., stringsAsFactors = default.stringsAsFactors()) {
   if (!length(row.names))
     row.names <- vector("list", length(x@plates))
-  do.call(rbind, mapply(as.data.frame, x@plates, row.names, SIMPLIFY = FALSE,
-    MoreArgs = list(optional = optional, sep = sep, ...,
-    stringsAsFactors = stringsAsFactors), USE.NAMES = FALSE))
+  do.call(rbind, mapply(as.data.frame, x = x@plates, row.names = row.names,
+    MoreArgs = list(optional = optional, sep = sep, csv.data = csv.data,
+      settings = settings, include = include, ...,
+      stringsAsFactors = stringsAsFactors),
+    SIMPLIFY = FALSE, USE.NAMES = FALSE))
 }, sealed = SEALED)
 
 setOldClass("kegg_compounds")
