@@ -27,10 +27,8 @@ if (!exists("TEST.DIR"))
 ## UNTESTED
 
 
-## param_names
-test_that("param_names() is consistent with other settings", {
-  expect_true(OPM_OPTIONS$curve.param %in% c(param_names(), "disc"))
-})
+## pe_and_ci
+## UNTESTED
 
 
 ################################################################################
@@ -95,7 +93,7 @@ test_that("OPMS objects can be aggregated using the fast method", {
   agg.got <- aggregated(fast.agg)
   expect_is(agg.got, "list")
   expect_equal(length(agg.got), length(fast.agg))
-  expect_true(all(sapply(agg.got, is.matrix)))
+  expect_true(all(vapply(agg.got, is.matrix, NA)))
   other.agg <- aggregated(SMALL.AGG)
   for (agg in agg.got) {
     expect_equal(colnames(agg)[1:10], colnames(other.agg))
@@ -105,46 +103,5 @@ test_that("OPMS objects can be aggregated using the fast method", {
 })
 
 
-## do_aggr
-test_that("matrices can be aggregated", {
-
-  x <- matrix(1:10, ncol = 2L)
-  colnames(x) <- LETTERS[1:2]
-  rownames(x) <- letters[1:5]
-
-  groups <- list(Y = c("a", "a", "b", "a", "b"))
-  got <- do_aggr(x, groups, mean)
-  expect_is(got, "matrix")
-  expect_equal(rownames(got), levels(as.factor(groups$Y)))
-  expect_equal(colnames(got), colnames(x))
-
-  groups <- c(groups, list(Z = rep("z", 5L)))
-  got <- do_aggr(x, groups, mean)
-  expect_is(got, "matrix")
-  exp.rn <- paste(levels(as.factor(groups$Y)), levels(as.factor(groups$Z)),
-    sep = ".")
-  expect_equal(rownames(got), exp.rn)
-  expect_equal(colnames(got), colnames(x))
-
-  got <- do_aggr(x, groups, mean, sep = "||")
-  exp.rn <- paste(levels(as.factor(groups$Y)), levels(as.factor(groups$Z)),
-    sep = "||")
-  expect_equal(rownames(got), exp.rn)
-  expect_equal(colnames(got), colnames(x))
-
-})
-
-
-################################################################################
-
-
-## pe_and_ci
-## UNTESTED
-
-
-## fast_estimate
-## UNTESTED
-
-
 ################################################################################
 
