@@ -30,6 +30,10 @@ test_that("metadata can be included and CSV keys removed", {
 })
 
 
+## edit
+## UNTESTED
+
+
 ################################################################################
 
 
@@ -124,6 +128,54 @@ test_that("the metadata can be modified using a mapping function", {
 })
 
 
+
+################################################################################
+
+
+## metadata
+test_that("missing metadata result in an error if requested", {
+  expect_is(OPM.1, "OPM")
+  expect_equal(metadata(OPM.1), list())
+  expect_equal(metadata(OPM.1, "Organism"), NULL)
+  expect_error(metadata(OPM.1, "Organism", strict = TRUE))
+})
+
+## metadata
+test_that("metadata have be included in example OPM object", {
+  expect_is(OPM.WITH.MD, "OPM")
+  exp.list <- list(File = csv_data(OPM.1, what = "filename"), Organism = ORGN)
+  expect_equal(metadata(OPM.WITH.MD), exp.list)
+  expect_equal(metadata(OPM.WITH.MD, "Organism"), ORGN)
+  expect_equal(metadata(OPM.WITH.MD, list("File", "Organism")), exp.list)
+  exp.list$Organism <- NULL
+  exp.list$Org <- ORGN
+  expect_equal(metadata(OPM.WITH.MD, list("File", "Org"), exact = FALSE),
+    exp.list)
+  exp.list$Org <- NULL
+  exp.list <- c(exp.list, list(Org = NULL))
+  expect_equal(metadata(OPM.WITH.MD, list("File", "Org"), exact = TRUE),
+    exp.list)
+})
+
+## metadata
+test_that("the OPMS metadata can be queried", {
+  md.got <- metadata(OPMS.INPUT)
+  expect_is(md.got, "list")
+  expect_equal(length(md.got), length(OPMS.INPUT))
+  expect_true(all(vapply(md.got, is.list, NA)))
+  md.got <- metadata(OPMS.INPUT, "organism")
+  expect_is(md.got, "character")
+  expect_equal(length(md.got), length(OPMS.INPUT))
+  md.got <- metadata(OPMS.INPUT, list("not.there"))
+  expect_is(md.got, "list")
+  expect_true(all(vapply(md.got, is.list, NA)))
+  expect_true(all(vapply(md.got, names, "") == "not.there"))
+  expect_true(all(vapply(md.got, function(x) is.null(x$not.there), NA)))
+  expect_error(md.got <- metadata(OPMS.INPUT, list("not.there"), strict = TRUE))
+  expect_equal(metadata(OPMS.INPUT), metadata(THIN.AGG))
+})
+
+
 ################################################################################
 
 
